@@ -11,8 +11,10 @@
 #' @details
 #' MRAN has data starting from September 17 2014. Data for a few selected dates
 #' before September 17 2014 can be obtained from the dataset
-#' [`Ecdat::CRANpackages`]. A more complete dataset ranging from 2001 until
-#' today can be obtained with [`get_cran_history()`].
+#' [`CRANpackages`](https://www.rdocumentation.org/packages/Ecdat/versions/0.3-9/topics/CRANpackages)
+#' from the package [`Ecdat`](https://cran.r-project.org/package=Ecdat).
+#' A more complete dataset ranging from 2001 until
+#' today is included in the package as [`cran_history`].
 #'
 #' Note that for some dates there is no snapshot on MRAN. The function will
 #' return an error in those cases.
@@ -21,7 +23,7 @@
 #' the number of available packages as an integer or the R version number as
 #' a character
 #'
-#' @seealso [`get_cran_history()`]
+#' @seealso [`cran_history`]
 #'
 #' @export
 
@@ -84,40 +86,3 @@ get_mran_page <- function(date, type) {
 
   page
 }
-
-
-#' History of the Number of Available CRAN Packages
-#'
-#' Get a data frame containing the number of packages available for historic
-#' dates back to 21 June 2001.
-#'
-#' @details
-#' Data on the number of packages on CRAN between 2001-06-21 and 2014-04-13
-#' is obtained from [`Ecdat::CRANpackages`].
-#' This data was collected by John Fox and Spencer Graves. Intervals between
-#' data points are irregularly spaced.
-#'
-#' Newer data was obtained using the function [`n_available_packages()`] which
-#' extracts the information from CRAN snapshots on MRAN. One data point per
-#' quarter is available starting on 2014-10-01.
-#'
-#' @return
-#' a tibble with columns `date` and `n_packages`
-#'
-#' @examples
-#' library(ggplot2)
-#' cran_history <- get_cran_history()
-#' ggplot(cran_history, aes(x = date, y = n_packages)) +
-#'   geom_point()
-#'
-#' @export
-
-get_cran_history <- function() {
-
-  Ecdat::CRANpackages %>%
-    dplyr::as_tibble() %>%
-    dplyr::select(date = "Date", n_packages = "Packages",
-                  version = "Version", source = "Source") %>%
-    dplyr::mutate(source = stringr::str_trim(.data$source)) %>%
-    dplyr::bind_rows(cran_history)
-}
