@@ -6,7 +6,8 @@ test_that("check get_required_packages()", {
             "kableExtra", "tidyverse", "rmarkdown", "caret", "reshape2",
             "lubridate", "ggrepel", "writexl", "cowplot", "DT", "gutenbergr",
             "tidytext", "rvest", "Lahman", "pdftools", "HistData", "titanic",
-            "BiocManager", "waldo", "knitr", "hexbin", "patchwork", "GGally")
+            "BiocManager", "waldo", "cluster", "ggfortify",
+            "knitr", "hexbin", "patchwork", "GGally")
   expect_true(all(pkgs %in% req_pkgs))
   expect_false(any(c("R", "testthat", "usethis", "vdiffr", "covr") %in% req_pkgs))
 })
